function [ w, cvx_optval ] = fmmp2(A)

% The FMMP edge weights are given the SDP:
%
%   maximize    gamma
%   subject to  gamma*I <= L + beta*ones(m,m);
%               w >= 0,  
%               ones(m,1)'w == 1
%
% where the variables are edge weights w in R^m and s in R.
% Here L is the weighted Laplacian defined by L = A*diag(w)*A'.
% The optimal value is s, and is returned in the second output.
%


[n,m] = size(A);
I = eye(n-1, n-1);
P = null( ones(1,n) );
cvx_begin sdp quiet
    variable w(m,1)         % edge weights
    variable s          % epigraph variable
    variable L(n,n) symmetric
    
    maximize ( s )
    subject to
        % 1. Laplacian Matrix . 
        L == A * diag(w) * A';
        
        % 2. w  ִ´. 0 Ŀϰ, w sum 1̾ Ѵ. 
        w > 0; 
        ones(m,1)'*w == 1;
        
        % 3. one vector Null Space span P ʿ  L eigenvalue ũѴ. 
        s*I <= P'*L*P;
cvx_end 

%%
temp = 0;


