function [ w, cvx_optval ] = mter(A)
% Minimum total effective resistance
% The FMMP edge weights are given the SDP:
%
%   maximize    Tr Y
%   subject to  [L + (1/n)*1*1t    I 
%                      I           Y  ] >= 0
%               w >= 0,  
%               ones(m,1)'w == 1
%
% where the variables are edge weights w in R^m and s in R.
% Here L is the weighted Laplacian defined by L = A*diag(w)*A'.
% The optimal value is s, and is returned in the second output.
%


[n,m] = size(A);
cvx_begin sdp quiet
    variable w(m,1)         % edge weights
    variable s          % epigraph variable
    variable L(n,n) symmetric
    variable Y(n,n) symmetric
    
    minimize ( trace(Y) )
    subject to
        % 1. Laplacian Matrix . 
        L == A * diag(w) * A';
        
        % 2. w  ִ´. 0 Ŀϰ, w sum 1̾ Ѵ. 
        w > 0; 
        ones(m,1)'*w == 1;
        
        % 3. SDP
        [ L + (1/n)*ones(n, n)   eye(n,n) ; 
                 eye(n,n)          Y       ] >= 0;
cvx_end 

%%
temp = 0;


